@@ -10,11 +10,13 @@ def main(argv=None):
 
     argv = argv or sys.argv
 
-    parser = ArgumentParser(version=avro.__version__,
+    parser = ArgumentParser(
         description='iter over avro file, emit records as JSON')
     parser.add_argument('file', help='file(s) to parse', nargs='+')
     parser.add_argument('--schema', help='dump schema instead of records',
                         action='store_true', default=False)
+    parser.add_argument('--version', action='version',
+            version='fastavro {0}'.format(avro.__version__))
     args = parser.parse_args(argv[1:])
 
     for filename in args.file:
